#
# spec file for package python-monascaclient
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-monascaclient
Version:        2.5.0
Release:        1.5
Summary:        Python API and CLI for OpenStack Monasca
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://docs.openstack.org/python-monascaclient
Source0:        https://files.pythonhosted.org/packages/source/p/python-monascaclient/python-monascaclient-2.5.0.tar.gz
BuildRequires:  openstack-macros
BuildRequires:  python3-PrettyTable >= 0.7.2
BuildRequires:  python3-PyYAML >= 3.12
BuildRequires:  python3-fixtures
BuildRequires:  python3-openstackdocstheme
BuildRequires:  python3-osc-lib >= 1.8.0
BuildRequires:  python3-oslo.concurrency
BuildRequires:  python3-oslo.serialization >= 2.18.0
BuildRequires:  python3-oslo.utils >= 3.33.0
BuildRequires:  python3-oslotest
BuildRequires:  python3-pbr >= 2.0.0
BuildRequires:  python3-stestr
BuildRequires:  python3-testscenarios
BuildRequires:  python3-testtools
BuildArch:      noarch

%description
This is a client library for Monasca built to interface with the Monasca API. It
provides a Python API (the ``monascaclient`` module) and a command-line tool
(``monasca``).

%package -n python3-monascaclient
Summary:        Python API and CLI for OpenStack Monasca
Requires:       python3-Babel >= 2.3.4
Requires:       python3-PrettyTable >= 0.7.2
Requires:       python3-PyYAML >= 3.12
Requires:       python3-iso8601 >= 0.1.11
Requires:       python3-osc-lib >= 1.8.0
Requires:       python3-oslo.serialization >= 2.18.0
Requires:       python3-oslo.utils >= 3.33.0
Requires:       python3-pbr >= 2.0.0
Requires:       python3-requests
Requires:       python3-six
%if 0%{?suse_version}
Obsoletes:      python2-monascaclient < 2.0.0
%endif

%description -n python3-monascaclient
This is a client library for Monasca built to interface with the Monasca API. It
provides a Python API (the ``monascaclient`` module) and a command-line tool
(``monasca``).

The Monasca Client was written using the OpenStack Heat Python client as a framework.

%prep
%autosetup -p1 -n python-monascaclient-2.5.0
%py_req_cleanup

%build
%{py3_build}

%install
%{py3_install}

%check
python3 -m stestr.cli run

%files -n python3-monascaclient
%doc README.rst
%license LICENSE
%{python3_sitelib}/monascaclient
%{python3_sitelib}/*.egg-info
%{_bindir}/monasca

%changelog
* Tue May 24 2022 cloud-devel@suse.de
- update to version 2.5.0
  - Add Python3 yoga unit tests
  - Update master for stable/xena
* Mon Dec  6 2021 cloud-devel@suse.de
- update to version 2.4.0
  - Fix Docker build
  - Add Python3 xena unit tests
  - Update master for stable/wallaby
  - Fix zuul publish docker image job
* Sun May  2 2021 cloud-devel@suse.de
- update to version 2.3.0
  - Update doc8 version
  - Update master for stable/victoria
  - Remove six
  - Add doc/requirements
  - Uncap PrettyTable
  - Add Python3 wallaby unit tests
  - Fix zuul publish docker image job
* Fri Oct  9 2020 cloud-devel@suse.de
- update to version 2.2.1
  - Stop to use the __future__ module.
  - Update CONTRIBUTING.rst
  - Add py38 package metadata
  - Bump default tox env from py37 to py38
  - Add releasenotes link to README
  - Switch to newer openstackdocstheme and reno versions
  - Add Python3 victoria unit tests
  - Update master for stable/ussuri
  - Fix mock import statements
  - Fix hacking min version to 3.0.1
  - Use unittest.mock instead of third party mock
* Tue May 12 2020 cloud-devel@suse.de
- update to version 2.1.0
  - Cleanup py27 support
  - Update master for stable/train
  - Update hacking for Python3
  - [ussuri][goal] Drop python 2.7 support and testing
  - Update the constraints url
  - Sync Sphinx requirement
  - Don't hard code notification types into Monasca client
  - Allow users to set periodic notifications on all notification types
  - Switch to Ussuri jobs
* Mon Mar 23 2020 Dirk Mueller <dmueller@suse.com>
- add obsoletes
* Wed Mar 11 2020 Dirk Mueller <dmueller@suse.com>
- switch to python 3.x only
* Wed Oct  9 2019 cloud-devel@suse.de
- update to version 1.16.0
  - Fix metric list formatting with Python 3
  - Push Docker image to Docker Hub
  - Create Docker image and build in Zuul
  - OpenDev Migration Patch
  - Dropping the py35 testing
  - Update master for stable/stein
  - Replace git.openstack.org URLs with opendev.org URLs
  - Replace openstack.org git:// URLs with https://
  - Change repository links usage in Dockerfile and build image
  - Switch python3 versions of test jobs to match Train PTI
  - Add Python 3 Train unit tests
* Mon Jun 17 2019 cloud-devel@suse.de
- update to version 1.15.0
  - Replace openstack.org git:// URLs with https://
  - Update .gitreview for stable/stein
  - Fix metric list formatting with Python 3
  - Update UPPER_CONSTRAINTS_FILE for stable/stein
* Mon Apr  8 2019 cloud-devel@suse.de
- update to version 1.14.0
  - Update hacking version
  - Add using requirements.txt to tox tests run
  - Use templates for docs, cover and lower-constraints
  - Add Python 3.6 classifier to setup.cfg
  - Remove setup.py check from pep8 job
  - Change openstack-dev to openstack-discuss
  - Update json module to jsonutils
  - Return status from running command
  - Update reno for stable/rocky
  - fix tox python3 overrides
  - Don't quote {posargs} in tox.ini
  - switch documentation job to new PTI
  - Add python 3.6 unit test job
  - add python 3.6 unit test job
  - Fix alarm-definition-list in Python 3
  - add python 3.7 unit test job
  - import zuul job settings from project-config
* Mon Sep  3 2018 cloud-devel@suse.de
- update to version 1.12.1
  - fix tox python3 overrides
  - Remove the duplicated word
  - Remove unused TimingSession class
  - Update reno for stable/queens
  - Update links in README
  - Redistribute README to doc/source
  - Trivial: Update pypi url to new url
  - Add syntax check for reStructuredText
  - Update pep8 checks
  - Remove testrepository and .testr.conf
  - replace unicode with six.text_type
  - Move CLI usage examples to doc/cli directory
  - Fix rst errors in README
  - Restore old content of reference/index.rst
  - Switch to using stestr
  - Clean up tox.ini
  - Updated from global requirements
  - add lower-constraints job
  - Clean up README.rst
* Tue Mar  6 2018 tbechtold@suse.com
- Drop unused Requires for python-oslo.service
* Fri Feb 23 2018 cloud-devel@suse.de
- update to version 1.10.0
  - Updated from global requirements
  - TrivialFix: remove redundant import alias
  - Update usage examples
- Switch to stable/queens spec template
* Tue Jan 30 2018 cloud-devel@suse.de
- update to version 1.9.0
  - Updated from global requirements
  - Avoid tox_install.sh for constraints support
  - Enable client documentation
* Mon Jan 15 2018 cloud-devel@suse.de
- update to version 1.8.0
  - Exclude tests from coverage
  - Cleanup repo and update documentation
  - Update the documentation link for doc migration
  - Fix auth version detection
  - Allow to reuse the session
  - Updated from global requirements
* Thu Aug 24 2017 cloud-devel@suse.de
- update to version 1.7.0
  - Bringing back backward compatybility
  - Integrate client with osc-lib
  - Updated from global requirements
  - Added support for os_tenant_{name,id} after os_project_
* Mon Aug  7 2017 cloud-devel@suse.de
- update to version 1.6.0
  - Added support for os_auth_version when os_auth_url is unversiond
  - Optimize the link address
  - Remove unused requirements
  - Fix: CLI metric-create using project-id fails
  - Replacing six.iteritems() with .items()
  - Turn on bandit check as part of pep8
  - Fix notification-patch CLI fails if type not given
  - Migrate fully to ostestr
  - Updated from global requirements
- drop 0001-Added-support-for-os_auth_version-when-os_auth_url-i.patch .
  applied upstream.
* Tue Apr 18 2017 tbechtold@suse.com
- Add 0001-Added-support-for-os_auth_version-when-os_auth_url-i.patch
* Mon Feb 13 2017 cloud-devel@suse.de
- update to version 1.5.0:
  - Add CONTRIBUTING.rst
  - Updated from global requirements
  - Show team and repo badges on README
  - Don't send X-Auth- headers in requests
  - H803 hacking have been deprecated
  - Use requests-mock instead of custom fakes
  - Use the new copy of tox_install.sh for global constraints support
  - Remove support for py33
  - Typo fix: recieve => receive
  - Add __ne__ built-in function
  - Use correct ENV variables for scoping
* Mon Feb 13 2017 cloud-devel@suse.de
- update to version 1.4.0:
  - Remove a space of Docstring
  - Fix dimension validation and help message for alarm count
  - Patch-notification failed with period=0
  - Fix LOG.warn to LOG.warning
  - move old apiclient code out of openstack/common
  - Dimension value list doesn't recognize dimension name input
  - Change LOG.warn to LOG.warning
  - Add notification-patch into CLI
  - Add support for new rest api notification-type-list
  - Fix monasca enpoint port in example and README
  - Remove discover from test-requirements
  - Add list_next for pagination
  - Add list dimension names and values in CLI
  - Changed author and author-email
  - Prevent potentially destructive updates on data
  - Add py35 tox environment
  - Add state-updated-timestamp filter to alarm count CLI
  - use six.moves.urllib.parse instead of py3kcompat
  - remove unused openstack/common/gettextutils.py
  - Use constraints everywhere
  - Fixes H904: wrapping using parantheses
  - Correct reraising of exception
  - Fix __str__ not returning a String for KeystoneException
  - Sync tools/tox_install.sh
  - Remove white space between print and ()
  - Fix monasca notification-show help message
  - Sample nagios plugin and examples directory.
  - Updated from global requirements
  - Delete deprecated Hacking in tox.ini
* Wed Dec  7 2016 dmueller@suse.com
- Initial package (1.2.0)
